[![Build Status](https://travis-ci.com/yandexdataschool/QuantileTransformerTF.svg?branch=master)](https://travis-ci.com/yandexdataschool/QuantileTransformerTF) [![DOI](https://zenodo.org/badge/156366202.svg)](https://zenodo.org/badge/latestdoi/156366202)

# QuantileTransformerTF
Tensorflow implementation of sklearn.preprocessing.QuantileTransformer

Please cite as [![DOI](https://zenodo.org/badge/156366202.svg)](https://zenodo.org/badge/latestdoi/156366202)
